import React, { createContext, useContext, useEffect, useState } from "react";
const envContext = createContext({});
export const Environment = ({ children, url = "/env.json", preferLocal = true, Loader = () => null, ErrorMessage = () => React.createElement(React.Fragment, null, "Error loading environment"), }) => {
    const [environment, setEnvironment] = useState();
    const [isError, setIsError] = useState(false);
    useEffect(() => {
        var _a;
        const abortCtrl = new AbortController();
        const opts = { signal: abortCtrl.signal };
        const localEnv = (_a = window) === null || _a === void 0 ? void 0 : _a.env;
        if (preferLocal && localEnv) {
            setEnvironment(localEnv);
            return;
        }
        fetch(url, opts)
            .then((response) => response.json())
            .then((data) => setEnvironment(data))
            .catch((error) => {
            console.log(error.message);
            setIsError(true);
        });
        return () => abortCtrl.abort();
    }, [url, setEnvironment]);
    if (isError) {
        return React.createElement(ErrorMessage, null);
    }
    if (environment) {
        return React.createElement(Loader, null);
    }
    return React.createElement(envContext.Provider, { value: {} }, children);
};
export const useEnvironment = () => useContext(envContext);
//# sourceMappingURL=index.js.map